// This file has been created automatically by 'rfGenerateMaths'
#include <Rmath.h>
#include "RF.h"
#include "primitive.h"
void Mathacos(double *x, cov_model *cov, double *v){
MATH_DEFAULT
*v = ACOS(w[0]); 
}


void Mathasin(double *x, cov_model *cov, double *v){
MATH_DEFAULT
*v = ASIN(w[0]); 
}


void Mathatan(double *x, cov_model *cov, double *v){
MATH_DEFAULT
*v = ATAN(w[0]); 
}


void Mathatan2(double *x, cov_model *cov, double *v){
MATH_DEFAULT
*v = atan2(w[0], w[1]); 
}


void Mathcos(double *x, cov_model *cov, double *v){
MATH_DEFAULT
*v = COS(w[0]); 
}


void Mathsin(double *x, cov_model *cov, double *v){
MATH_DEFAULT
*v = SIN(w[0]); 
}


void Mathtan(double *x, cov_model *cov, double *v){
MATH_DEFAULT
*v = TAN(w[0]); 
}


void Mathacosh(double *x, cov_model *cov, double *v){
MATH_DEFAULT
*v = acosh(w[0]); 
}


void Mathasinh(double *x, cov_model *cov, double *v){
MATH_DEFAULT
*v = asinh(w[0]); 
}


void Mathatanh(double *x, cov_model *cov, double *v){
MATH_DEFAULT
*v = atanh(w[0]); 
}


void Mathcosh(double *x, cov_model *cov, double *v){
MATH_DEFAULT
*v = cosh(w[0]); 
}


void Mathsinh(double *x, cov_model *cov, double *v){
MATH_DEFAULT
*v = sinh(w[0]); 
}


void Mathtanh(double *x, cov_model *cov, double *v){
MATH_DEFAULT
*v = tanh(w[0]); 
}


void Mathexp(double *x, cov_model *cov, double *v){
MATH_DEFAULT
*v = EXP(w[0]); 
}


void Mathlog(double *x, cov_model *cov, double *v){
MATH_DEFAULT
*v = LOG(w[0]); 
}


void Mathexpm1(double *x, cov_model *cov, double *v){
MATH_DEFAULT
*v = expm1(w[0]); 
}


void Mathlog1p(double *x, cov_model *cov, double *v){
MATH_DEFAULT
*v = log1p(w[0]); 
}


void Mathlogb(double *x, cov_model *cov, double *v){
MATH_DEFAULT
*v = logb(w[0]); 
}


void Mathexp2(double *x, cov_model *cov, double *v){
MATH_DEFAULT
*v = exp2(w[0]); 
}


void Mathlog2(double *x, cov_model *cov, double *v){
MATH_DEFAULT
*v = log2(w[0]); 
}


void Mathpow(double *x, cov_model *cov, double *v){
MATH_DEFAULT
*v = POW(w[0], w[1]); 
}


void Mathsqrt(double *x, cov_model *cov, double *v){
MATH_DEFAULT
*v = SQRT(w[0]); 
}


void Mathhypot(double *x, cov_model *cov, double *v){
MATH_DEFAULT
*v = hypot(w[0], w[1]); 
}


void Mathcbrt(double *x, cov_model *cov, double *v){
MATH_DEFAULT
*v = cbrt(w[0]); 
}


void Mathceil(double *x, cov_model *cov, double *v){
MATH_DEFAULT
*v = CEIL(w[0]); 
}


void Mathfabs(double *x, cov_model *cov, double *v){
MATH_DEFAULT
*v = FABS(w[0]); 
}


void Mathfloor(double *x, cov_model *cov, double *v){
MATH_DEFAULT
*v = FLOOR(w[0]); 
}


void Mathfmod(double *x, cov_model *cov, double *v){
MATH_DEFAULT
  *v = std::fmod(w[0], w[1]); 
}



void Mathround(double *x, cov_model *cov, double *v){
MATH_DEFAULT
*v = ROUND(w[0]); 
}


void Mathtrunc(double *x, cov_model *cov, double *v){
MATH_DEFAULT
*v = TRUNC(w[0]); 
}


/*

void Mathnearbyint(double *x, cov_model *cov, double *v){
MATH_DEFAULT
  *v = std::nearbyint(w[0]); 
}

void Mathlrint(double *x, cov_model *cov, double *v){
MATH_DEFAULT
  *v = std::lrint(w[0]); 
}


void Mathllrint(double *x, cov_model *cov, double *v){
MATH_DEFAULT
*v = llrint(w[0]); 
}

void Mathlround(double *x, cov_model *cov, double *v){
  MATH_DEFAULT
  *v = l ROUND(w[0]); 
}


void Mathllround(double *x, cov_model *cov, double *v){
MATH_DEFAULT
*v = ll ROUND(w[0]); 
}

void Mathcopysign(double *x, cov_model *cov, double *v){
MATH_DEFAULT
*v = copysign(w[0], w[1]); 
}
*/

void Matherf(double *x, cov_model *cov, double *v){
MATH_DEFAULT
*v = erf(w[0]); 
}


void Matherfc(double *x, cov_model *cov, double *v){
MATH_DEFAULT
*v = erfc(w[0]); 
}


void Mathtgamma(double *x, cov_model *cov, double *v){
MATH_DEFAULT
*v = tgamma(w[0]); 
}


void Mathlgamma(double *x, cov_model *cov, double *v){
MATH_DEFAULT
  *v = lgammafn(w[0]);
}


void Mathrint(double *x, cov_model *cov, double *v){
MATH_DEFAULT
*v = rint(w[0]); 
}


void Mathnextafter(double *x, cov_model *cov, double *v){
MATH_DEFAULT
*v = nextafter(w[0], w[1]); 
}


void Mathnexttoward(double *x, cov_model *cov, double *v){
MATH_DEFAULT
*v = nexttoward(w[0], w[1]); 
}


void Mathremainder(double *x, cov_model *cov, double *v){
MATH_DEFAULT
*v = remainder(w[0], w[1]); 
}


void Mathfdim(double *x, cov_model *cov, double *v){
MATH_DEFAULT
*v = fdim(w[0], w[1]); 
}


void Mathfmax(double *x, cov_model *cov, double *v){
MATH_DEFAULT
*v = fmax(w[0], w[1]); 
}


void Mathfmin(double *x, cov_model *cov, double *v){
MATH_DEFAULT
*v = fmin(w[0], w[1]); 
}


void includeStandardMath() {
IncludeModel(".acos", MathDefinition, 0, 0, 1, NULL, XONLY,
	 PREVMODELI,checkMath,rangeMath, PREF_TREND,
	false, SCALAR, PREVMODEL_DEP, false, false); 
nickname("acos");
kappanames("a", REALSXP);
addCov(Mathacos, NULL, NULL);
AddVariant(TrendType, PREVMODELI);

IncludeModel(".asin", MathDefinition, 0, 0, 1, NULL, XONLY,
	 PREVMODELI,checkMath,rangeMath, PREF_TREND,
	false, SCALAR, PREVMODEL_DEP, false, false); 
nickname("asin");
kappanames("a", REALSXP);
addCov(Mathasin, NULL, NULL);
AddVariant(TrendType, PREVMODELI);

IncludeModel(".atan", MathDefinition, 0, 0, 1, NULL, XONLY,
	 PREVMODELI,checkMath,rangeMath, PREF_TREND,
	false, SCALAR, PREVMODEL_DEP, false, false); 
nickname("atan");
kappanames("a", REALSXP);
addCov(Mathatan, NULL, NULL);
AddVariant(TrendType, PREVMODELI);

IncludeModel(".atan2", MathDefinition, 0, 0, 2, NULL, XONLY,
	 PREVMODELI,checkMath,rangeMath, PREF_TREND,
	false, SCALAR, PREVMODEL_DEP, false, false); 
nickname("atan2");
kappanames("a", REALSXP, "b", REALSXP);
addCov(Mathatan2, NULL, NULL);
AddVariant(TrendType, PREVMODELI);

IncludeModel(".cos", MathDefinition, 0, 0, 1, NULL, XONLY,
	 PREVMODELI,checkMath,rangeMath, PREF_TREND,
	false, SCALAR, PREVMODEL_DEP, false, false); 
nickname("cos");
kappanames("a", REALSXP);
addCov(Mathcos, NULL, NULL);
AddVariant(TrendType, PREVMODELI);

IncludeModel(".sin", MathDefinition, 0, 0, 1, NULL, XONLY,
	 PREVMODELI,checkMath,rangeMath, PREF_TREND,
	false, SCALAR, PREVMODEL_DEP, false, false); 
nickname("sin");
kappanames("a", REALSXP);
addCov(Mathsin, NULL, NULL);
AddVariant(TrendType, PREVMODELI);

IncludeModel(".tan", MathDefinition, 0, 0, 1, NULL, XONLY,
	 PREVMODELI,checkMath,rangeMath, PREF_TREND,
	false, SCALAR, PREVMODEL_DEP, false, false); 
nickname("tan");
kappanames("a", REALSXP);
addCov(Mathtan, NULL, NULL);
AddVariant(TrendType, PREVMODELI);

IncludeModel(".acosh", MathDefinition, 0, 0, 1, NULL, XONLY,
	 PREVMODELI,checkMath,rangeMath, PREF_TREND,
	false, SCALAR, PREVMODEL_DEP, false, false); 
nickname("acosh");
kappanames("a", REALSXP);
addCov(Mathacosh, NULL, NULL);
AddVariant(TrendType, PREVMODELI);

IncludeModel(".asinh", MathDefinition, 0, 0, 1, NULL, XONLY,
	 PREVMODELI,checkMath,rangeMath, PREF_TREND,
	false, SCALAR, PREVMODEL_DEP, false, false); 
nickname("asinh");
kappanames("a", REALSXP);
addCov(Mathasinh, NULL, NULL);
AddVariant(TrendType, PREVMODELI);

IncludeModel(".atanh", MathDefinition, 0, 0, 1, NULL, XONLY,
	 PREVMODELI,checkMath,rangeMath, PREF_TREND,
	false, SCALAR, PREVMODEL_DEP, false, false); 
nickname("atanh");
kappanames("a", REALSXP);
addCov(Mathatanh, NULL, NULL);
AddVariant(TrendType, PREVMODELI);

IncludeModel(".cosh", MathDefinition, 0, 0, 1, NULL, XONLY,
	 PREVMODELI,checkMath,rangeMath, PREF_TREND,
	false, SCALAR, PREVMODEL_DEP, false, false); 
nickname("cosh");
kappanames("a", REALSXP);
addCov(Mathcosh, NULL, NULL);
AddVariant(TrendType, PREVMODELI);

IncludeModel(".sinh", MathDefinition, 0, 0, 1, NULL, XONLY,
	 PREVMODELI,checkMath,rangeMath, PREF_TREND,
	false, SCALAR, PREVMODEL_DEP, false, false); 
nickname("sinh");
kappanames("a", REALSXP);
addCov(Mathsinh, NULL, NULL);
AddVariant(TrendType, PREVMODELI);

IncludeModel(".tanh", MathDefinition, 0, 0, 1, NULL, XONLY,
	 PREVMODELI,checkMath,rangeMath, PREF_TREND,
	false, SCALAR, PREVMODEL_DEP, false, false); 
nickname("tanh");
kappanames("a", REALSXP);
addCov(Mathtanh, NULL, NULL);
AddVariant(TrendType, PREVMODELI);

IncludeModel(".exp", MathDefinition, 0, 0, 1, NULL, XONLY,
	 PREVMODELI,checkMath,rangeMath, PREF_TREND,
	false, SCALAR, PREVMODEL_DEP, false, false); 
nickname("exp");
kappanames("a", REALSXP);
addCov(Mathexp, NULL, NULL);
AddVariant(TrendType, PREVMODELI);

IncludeModel(".log", MathDefinition, 0, 0, 1, NULL, XONLY,
	 PREVMODELI,checkMath,rangeMath, PREF_TREND,
	false, SCALAR, PREVMODEL_DEP, false, false); 
nickname("log");
kappanames("a", REALSXP);
addCov(Mathlog, NULL, NULL);
AddVariant(TrendType, PREVMODELI);

IncludeModel(".expm1", MathDefinition, 0, 0, 1, NULL, XONLY,
	 PREVMODELI,checkMath,rangeMath, PREF_TREND,
	false, SCALAR, PREVMODEL_DEP, false, false); 
nickname("expm1");
kappanames("a", REALSXP);
addCov(Mathexpm1, NULL, NULL);
AddVariant(TrendType, PREVMODELI);

IncludeModel(".log1p", MathDefinition, 0, 0, 1, NULL, XONLY,
	 PREVMODELI,checkMath,rangeMath, PREF_TREND,
	false, SCALAR, PREVMODEL_DEP, false, false); 
nickname("log1p");
kappanames("a", REALSXP);
addCov(Mathlog1p, NULL, NULL);
AddVariant(TrendType, PREVMODELI);

IncludeModel(".logb", MathDefinition, 0, 0, 1, NULL, XONLY,
	 PREVMODELI,checkMath,rangeMath, PREF_TREND,
	false, SCALAR, PREVMODEL_DEP, false, false); 
nickname("logb");
kappanames("a", REALSXP);
addCov(Mathlogb, NULL, NULL);
AddVariant(TrendType, PREVMODELI);

IncludeModel(".exp2", MathDefinition, 0, 0, 1, NULL, XONLY,
	 PREVMODELI,checkMath,rangeMath, PREF_TREND,
	false, SCALAR, PREVMODEL_DEP, false, false); 
nickname("exp2");
kappanames("a", REALSXP);
addCov(Mathexp2, NULL, NULL);
AddVariant(TrendType, PREVMODELI);

IncludeModel(".log2", MathDefinition, 0, 0, 1, NULL, XONLY,
	 PREVMODELI,checkMath,rangeMath, PREF_TREND,
	false, SCALAR, PREVMODEL_DEP, false, false); 
nickname("log2");
kappanames("a", REALSXP);
addCov(Mathlog2, NULL, NULL);
AddVariant(TrendType, PREVMODELI);

IncludeModel(".pow", MathDefinition, 0, 0, 2, NULL, XONLY,
	 PREVMODELI,checkMath,rangeMath, PREF_TREND,
	false, SCALAR, PREVMODEL_DEP, false, false); 
nickname("pow");
kappanames("a", REALSXP, "b", REALSXP);
addCov(Mathpow, NULL, NULL);
AddVariant(TrendType, PREVMODELI);

IncludeModel(".sqrt", MathDefinition, 0, 0, 1, NULL, XONLY,
	 PREVMODELI,checkMath,rangeMath, PREF_TREND,
	false, SCALAR, PREVMODEL_DEP, false, false); 
nickname("sqrt");
kappanames("a", REALSXP);
addCov(Mathsqrt, NULL, NULL);
AddVariant(TrendType, PREVMODELI);

IncludeModel(".hypot", MathDefinition, 0, 0, 2, NULL, XONLY,
	 PREVMODELI,checkMath,rangeMath, PREF_TREND,
	false, SCALAR, PREVMODEL_DEP, false, false); 
nickname("hypot");
kappanames("a", REALSXP, "b", REALSXP);
addCov(Mathhypot, NULL, NULL);
AddVariant(TrendType, PREVMODELI);

IncludeModel(".cbrt", MathDefinition, 0, 0, 1, NULL, XONLY,
	 PREVMODELI,checkMath,rangeMath, PREF_TREND,
	false, SCALAR, PREVMODEL_DEP, false, false); 
nickname("cbrt");
kappanames("a", REALSXP);
addCov(Mathcbrt, NULL, NULL);
AddVariant(TrendType, PREVMODELI);

IncludeModel(".ceil", MathDefinition, 0, 0, 1, NULL, XONLY,
	 PREVMODELI,checkMath,rangeMath, PREF_TREND,
	false, SCALAR, PREVMODEL_DEP, false, false); 
nickname("ceil");
kappanames("a", REALSXP);
addCov(Mathceil, NULL, NULL);
AddVariant(TrendType, PREVMODELI);

IncludeModel(".fabs", MathDefinition, 0, 0, 1, NULL, XONLY,
	 PREVMODELI,checkMath,rangeMath, PREF_TREND,
	false, SCALAR, PREVMODEL_DEP, false, false); 
nickname("fabs");
kappanames("a", REALSXP);
addCov(Mathfabs, NULL, NULL);
AddVariant(TrendType, PREVMODELI);

IncludeModel(".floor", MathDefinition, 0, 0, 1, NULL, XONLY,
	 PREVMODELI,checkMath,rangeMath, PREF_TREND,
	false, SCALAR, PREVMODEL_DEP, false, false); 
nickname("floor");
kappanames("a", REALSXP);
addCov(Mathfloor, NULL, NULL);
AddVariant(TrendType, PREVMODELI);

IncludeModel(".fmod", MathDefinition, 0, 0, 2, NULL, XONLY,
	 PREVMODELI,checkMath,rangeMath, PREF_TREND,
	false, SCALAR, PREVMODEL_DEP, false, false); 
nickname("fmod");
kappanames("a", REALSXP, "b", REALSXP);
addCov(Mathfmod, NULL, NULL);
AddVariant(TrendType, PREVMODELI);


IncludeModel(".round", MathDefinition, 0, 0, 1, NULL, XONLY,
	 PREVMODELI,checkMath,rangeMath, PREF_TREND,
	false, SCALAR, PREVMODEL_DEP, false, false); 
nickname("round");
kappanames("a", REALSXP);
addCov(Mathround, NULL, NULL);
AddVariant(TrendType, PREVMODELI);

IncludeModel(".trunc", MathDefinition, 0, 0, 1, NULL, XONLY,
	 PREVMODELI,checkMath,rangeMath, PREF_TREND,
	false, SCALAR, PREVMODEL_DEP, false, false); 
nickname("trunc");
kappanames("a", REALSXP);
addCov(Mathtrunc, NULL, NULL);
AddVariant(TrendType, PREVMODELI);


/*
IncludeModel(".nearbyint", MathDefinition, 0, 0, 1, NULL, XONLY,
	 PREVMODELI,checkMath,rangeMath, PREF_TREND,
	false, SCALAR, PREVMODEL_DEP, false, false); 
nickname("nearbyint");
kappanames("a", REALSXP);
addCov(Mathnearbyint, NULL, NULL);
AddVariant(TrendType, PREVMODELI);

IncludeModel(".lrint", MathDefinition, 0, 0, 1, NULL, XONLY,
	 PREVMODELI,checkMath,rangeMath, PREF_TREND,
	false, SCALAR, PREVMODEL_DEP, false, false); 
nickname("lrint");
kappanames("a", REALSXP);
addCov(Mathlrint, NULL, NULL);
AddVariant(TrendType, PREVMODELI);

IncludeModel(".llrint", MathDefinition, 0, 0, 1, NULL, XONLY,
	 PREVMODELI,checkMath,rangeMath, PREF_TREND,
	false, SCALAR, PREVMODEL_DEP, false, false); 
nickname("llrint");
kappanames("a", REALSXP);
addCov(Mathllrint, NULL, NULL);
AddVariant(TrendType, PREVMODELI);

IncludeModel(".lround", MathDefinition, 0, 0, 1, NULL, XONLY,
	 PREVMODELI,checkMath,rangeMath, PREF_TREND,
	false, SCALAR, PREVMODEL_DEP, false, false); 
nickname("lround");
kappanames("a", REALSXP);
addCov(Mathlround, NULL, NULL);
AddVariant(TrendType, PREVMODELI);


IncludeModel(".llround", MathDefinition, 0, 0, 1, NULL, XONLY,
	 PREVMODELI,checkMath,rangeMath, PREF_TREND,
	false, SCALAR, PREVMODEL_DEP, false, false); 
nickname("llround");
kappanames("a", REALSXP);
addCov(Mathllround, NULL, NULL);
AddVariant(TrendType, PREVMODELI);

IncludeModel(".copysign", MathDefinition, 0, 0, 2, NULL, XONLY,
	 PREVMODELI,checkMath,rangeMath, PREF_TREND,
	false, SCALAR, PREVMODEL_DEP, false, false); 
nickname("copysign");
kappanames("a", REALSXP, "b", REALSXP);
addCov(Mathcopysign, NULL, NULL);
AddVariant(TrendType, PREVMODELI);
*/

IncludeModel(".erf", MathDefinition, 0, 0, 1, NULL, XONLY,
	 PREVMODELI,checkMath,rangeMath, PREF_TREND,
	false, SCALAR, PREVMODEL_DEP, false, false); 
nickname("erf");
kappanames("a", REALSXP);
addCov(Matherf, NULL, NULL);
AddVariant(TrendType, PREVMODELI);

IncludeModel(".erfc", MathDefinition, 0, 0, 1, NULL, XONLY,
	 PREVMODELI,checkMath,rangeMath, PREF_TREND,
	false, SCALAR, PREVMODEL_DEP, false, false); 
nickname("erfc");
kappanames("a", REALSXP);
addCov(Matherfc, NULL, NULL);
AddVariant(TrendType, PREVMODELI);

IncludeModel(".tgamma", MathDefinition, 0, 0, 1, NULL, XONLY,
	 PREVMODELI,checkMath,rangeMath, PREF_TREND,
	false, SCALAR, PREVMODEL_DEP, false, false); 
nickname("tgamma");
kappanames("a", REALSXP);
addCov(Mathtgamma, NULL, NULL);
AddVariant(TrendType, PREVMODELI);

IncludeModel(".lgamma", MathDefinition, 0, 0, 1, NULL, XONLY,
	 PREVMODELI,checkMath,rangeMath, PREF_TREND,
	false, SCALAR, PREVMODEL_DEP, false, false); 
nickname("lgamma");
kappanames("a", REALSXP);
addCov(Mathlgamma, NULL, NULL);
AddVariant(TrendType, PREVMODELI);

IncludeModel(".rint", MathDefinition, 0, 0, 1, NULL, XONLY,
	 PREVMODELI,checkMath,rangeMath, PREF_TREND,
	false, SCALAR, PREVMODEL_DEP, false, false); 
nickname("rint");
kappanames("a", REALSXP);
addCov(Mathrint, NULL, NULL);
AddVariant(TrendType, PREVMODELI);

IncludeModel(".nextafter", MathDefinition, 0, 0, 2, NULL, XONLY,
	 PREVMODELI,checkMath,rangeMath, PREF_TREND,
	false, SCALAR, PREVMODEL_DEP, false, false); 
nickname("nextafter");
kappanames("a", REALSXP, "b", REALSXP);
addCov(Mathnextafter, NULL, NULL);
AddVariant(TrendType, PREVMODELI);

IncludeModel(".nexttoward", MathDefinition, 0, 0, 2, NULL, XONLY,
	 PREVMODELI,checkMath,rangeMath, PREF_TREND,
	false, SCALAR, PREVMODEL_DEP, false, false); 
nickname("nexttoward");
kappanames("a", REALSXP, "b", REALSXP);
addCov(Mathnexttoward, NULL, NULL);
AddVariant(TrendType, PREVMODELI);

IncludeModel(".remainder", MathDefinition, 0, 0, 2, NULL, XONLY,
	 PREVMODELI,checkMath,rangeMath, PREF_TREND,
	false, SCALAR, PREVMODEL_DEP, false, false); 
nickname("remainder");
kappanames("a", REALSXP, "b", REALSXP);
addCov(Mathremainder, NULL, NULL);
AddVariant(TrendType, PREVMODELI);

IncludeModel(".fdim", MathDefinition, 0, 0, 2, NULL, XONLY,
	 PREVMODELI,checkMath,rangeMath, PREF_TREND,
	false, SCALAR, PREVMODEL_DEP, false, false); 
nickname("fdim");
kappanames("a", REALSXP, "b", REALSXP);
addCov(Mathfdim, NULL, NULL);
AddVariant(TrendType, PREVMODELI);

IncludeModel(".fmax", MathDefinition, 0, 0, 2, NULL, XONLY,
	 PREVMODELI,checkMath,rangeMath, PREF_TREND,
	false, SCALAR, PREVMODEL_DEP, false, false); 
nickname("fmax");
kappanames("a", REALSXP, "b", REALSXP);
addCov(Mathfmax, NULL, NULL);
AddVariant(TrendType, PREVMODELI);

IncludeModel(".fmin", MathDefinition, 0, 0, 2, NULL, XONLY,
	 PREVMODELI,checkMath,rangeMath, PREF_TREND,
	false, SCALAR, PREVMODEL_DEP, false, false); 
nickname("fmin");
kappanames("a", REALSXP, "b", REALSXP);
addCov(Mathfmin, NULL, NULL);
AddVariant(TrendType, PREVMODELI);

}
